@@ -40,6 +40,9 @@
 					error = "Only one single trailing path wildcard (/*) allowed";
 				}
 			} catch (e) {
+				if (/^https?:\/\/\*\./.test(url)) {
+					return this.malformedUrl(url.replace("*.", ""));
+				}
 				error = "Invalid URL";
 				if (url && !url.includes("://")) error += ": missing protocol, either http:// or https://";
 				else if (url.endsWith("://")) error += ": missing domain name";
@@ -136,7 +139,7 @@
 		},
 		async swapSelection(list) {
 			let origin = list === Model.lists.black ? "white" : "black";
-		  await this.addToList(list, ...Array.map(
+		  await this.addToList(list, ...Array.prototype.map.call(
 				document.querySelectorAll(`select#${origin} option:checked`),
 				option => option.value)
 			);
@@ -186,7 +189,7 @@
 		async deleteSelection() {
 			for (let id of ["black", "white"]) {
 				let selection = document.querySelectorAll(`select#${id} option:checked`);
-				await Model.lists[id].remove(...Array.map(selection, option => option.value));
+				await Model.lists[id].remove(...Array.prototype.map.call(selection, option => option.value));
 			}
 			this.populateListUI();
 			this.syncAll();
